@@ -40,7 +40,7 @@
 
 #define GROUP "KHighscore"
 
-Q_LOGGING_CATEGORY(GAMES_HIGHSCORE, "games.highscore")
+Q_LOGGING_CATEGORY(GAMES_HIGHSCORE, "org.kde.games.highscore", QtWarningMsg)
 
 class KHighscore::KHighscorePrivate
 {
@@ -70,7 +70,6 @@ Q_GLOBAL_STATIC(KHighscoreLockedConfig, lockedConfig)
 KHighscore::KHighscore(bool forceLocal, QObject* parent)
     : QObject(parent), d(new KHighscorePrivate)
 {
-    QLoggingCategory::setFilterRules(QStringLiteral("games.highscore.debug = true")); //set to False when not needed
     init(forceLocal);
 }
 
