@@ -114,11 +114,11 @@ public:
 	 * reimplemented from @ref KChatBase
 	 * @return @ref KPlayer::name() for the player set by @ref setFromPlayer
 	 **/
-	QString fromName() const Q_DECL_OVERRIDE;
+	QString fromName() const override;
 
 
 public Q_SLOTS:
-	void addMessage(const QString& fromName, const QString& text) Q_DECL_OVERRIDE { KChatBase::addMessage(fromName, text);}
+	void addMessage(const QString& fromName, const QString& text) override { KChatBase::addMessage(fromName, text);}
 	virtual void addMessage(int fromId, const QString& text);
 
 	void slotReceiveMessage(int, const QByteArray&, quint32 receiver, quint32 sender);
@@ -209,7 +209,7 @@ protected Q_SLOTS:
 	void slotReceivePrivateMessage(int msgid, const QByteArray& buffer, quint32 sender, KPlayer* me);
 
 protected:
-	void returnPressed(const QString& text) Q_DECL_OVERRIDE;
+	void returnPressed(const QString& text) override;
 
 private:
 	void init(KGame* g, int msgid);
