@@ -84,7 +84,7 @@ public:
     */
    enum IOMode {GenericIO=1,KeyIO=2,MouseIO=4,ProcessIO=8,ComputerIO=16};
    /**
-    * Run time idendification. Predefined values are from IOMode
+    * Run time identification. Predefined values are from IOMode
     * You MUST overwrite this in derived classes!
     *
     * @return rtti value
@@ -202,7 +202,7 @@ public:
      * Note the widget you pass to the constructor must be
      * the main window of your application, e.g. view->parentWidget()
      * as QT does not forward your keyevents otherwise. This means
-     * that this might be a different widget comapred to the one you
+     * that this might be a different widget compared to the one you
      * use for mouse inputs!
      * Example:
      * \code
@@ -218,11 +218,11 @@ public:
     virtual ~KGameKeyIO();
 
     /**
-     * The idendification of the IO
+     * The identification of the IO
      *
      * @return KeyIO
      */
-    int rtti() const Q_DECL_OVERRIDE;
+    int rtti() const override;
 
 Q_SIGNALS:
       /**
@@ -231,7 +231,7 @@ Q_SIGNALS:
        * move for the player the device belongs to. If this is done
        * and the event is eaten eatevent needs to be set to true.
        * What move you generate (i.e. what you write to the stream)
-       * is totally up to you as it will not be evaluated but forwared
+       * is totally up to you as it will not be evaluated but forwarded
        * to the player's/game's  input move function
        * Example:
        * \code
@@ -252,7 +252,7 @@ protected:
        /**
        * Internal method to process the events
        */
-       bool eventFilter( QObject *o, QEvent *e ) Q_DECL_OVERRIDE;
+       bool eventFilter( QObject *o, QEvent *e ) override;
 
 private:
     friend class KGameKeyIOPrivate;
@@ -299,11 +299,11 @@ public:
      */
     void setMouseTracking(bool b);
     /**
-     * The idendification of the IO
+     * The identification of the IO
      *
      * @return MouseIO
      */
-    int rtti() const Q_DECL_OVERRIDE;
+    int rtti() const override;
 
 Q_SIGNALS:
       /**
@@ -331,7 +331,7 @@ protected:
       /**
       * Internal event filter
       */
-      bool eventFilter( QObject *o, QEvent *e ) Q_DECL_OVERRIDE;
+      bool eventFilter( QObject *o, QEvent *e ) override;
 
 private:
     friend class KGameMouseIOPrivate;
@@ -345,8 +345,8 @@ private:
  *  \class KGameProcessIO kgameio.h <KGame/KGameIO>
  *
  *  The KGameProcessIO class. It is used to create a computer player
- *  via a separate process and communicate transparetly with it.
- *  Its counterpart is the @ref KGameProcess class which needs
+ *  via a separate process and communicate transparently with it.
+ *  Its counterpart is the KGameProcess class which needs
  *  to be used by the computer player. See its documentation
  *  for the definition of the computer player.
  */
@@ -378,11 +378,11 @@ public:
     virtual ~KGameProcessIO();
 
     /**
-     * The idendification of the IO
+     * The identification of the IO
      *
      * @return ProcessIO
      */
-    int rtti() const Q_DECL_OVERRIDE;
+    int rtti() const override;
 
     /**
      * Send a message to the process. This is analogous to the sendMessage
@@ -416,7 +416,7 @@ public:
      * This function is called automatically when adding the IO to
      * a player.
      */
-    void initIO(KPlayer *p) Q_DECL_OVERRIDE;
+    void initIO(KPlayer *p) override;
 
     /**
      *  Notifies the IO device that the player's setTurn had been called
@@ -427,11 +427,11 @@ public:
      *
      *  @param turn is true/false
      */
-    void notifyTurn(bool turn) Q_DECL_OVERRIDE;
+    void notifyTurn(bool turn) override;
 
   protected:
     /**
-     * Internal ~ombined function for all message handling
+     * Internal combined function for all message handling
      **/
     void sendAllMessages(QDataStream &stream,int msgid, quint32 receiver, quint32 sender, bool usermsg);
 
@@ -456,7 +456,7 @@ Q_SIGNALS:
    *  void GameWindow::slotProcessQuery(QDataStream &stream,KGameProcessIO *reply)
    *  {
    *    int no;
-   *    stream >> no;  // We assume the process sends us an integer question numner
+   *    stream >> no;  // We assume the process sends us an integer question number
    *    if (no==1)     // but YOU have to do this in the process player
    *    {
    *      QByteArray buffer;
@@ -483,7 +483,7 @@ Q_SIGNALS:
   /** Text is received by the process on STDERR. This is usually a debug string.
     * @param msg The text
     */
-  void signalReceivedStderr(QString msg);
+  void signalReceivedStderr(const QString &msg);
 
 private:
     friend class KGameProcessIOPrivate;
@@ -523,7 +523,7 @@ public:
     KGameComputerIO(KPlayer* player);
     ~KGameComputerIO();
 
-    int rtti() const Q_DECL_OVERRIDE;
+    int rtti() const override;
 
     /**
      * The number of advance calls until the player (or rather: the IO)
